crystal_toolkit.components.search module — Crystal Toolkit documentation

# crystal_toolkit.components.search module

class crystal_toolkit.components.search.SearchComponent(*args, **kwargs)

  Bases: `MPComponent`

  generate_callbacks(app, cache)

    Generate all callbacks associated with the layouts in this app. Assume that “suppress_callback_exceptions” is True, since it is not always guaranteed that all layouts will be displayed to the end user at all times, but it’s important the callbacks are defined on the server.

  layout()
    Returns

      A Dash layout for the full component. Basic implementation

    provided, but should in general be overridden.